@@ -25,6 +25,8 @@ import javax.swing.JScrollPane;
 import javax.swing.JSplitPane;
 import javax.swing.JTabbedPane;
 import uk.ac.starlink.table.ColumnInfo;
+import uk.ac.starlink.table.Domain;
+import uk.ac.starlink.table.DomainMapper;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.gui.LabelledComponentStack;
@@ -123,7 +125,7 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
      * @param  table    table containing input data to plot
      */
     public BasicPlotGui( PlotType<P,A> plotType, Plotter<S> plotter,
-                                 StarTable table ) {
+                         StarTable table ) {
         super( new BorderLayout() );
         plotType_ = plotType;
         sfact_ = plotType.getSurfaceFactory();
@@ -401,14 +403,14 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
             CoordValue[] cvals = new CoordValue[ nc ];
             for ( int ic = 0; ic < nc; ic++ ) {
                 CoordInput cinput = clist_.get( ic );
-                @SuppressWarnings("rawtypes")
-                JComboBox[] entryBoxes = cinput.entryBoxes_;
+                JComboBox<?>[] entryBoxes = cinput.entryBoxes_;
                 int nin = entryBoxes.length;
                 String[] inExprs = new String[ nin ];
+                DomainMapper[] dms = new DomainMapper[ nin ];
                 for ( int ii = 0; ii < nin; ii++ ) {
                     inExprs[ ii ] = (String) entryBoxes[ ii ].getSelectedItem();
                 }
-                cvals[ ic ] = new CoordValue( cinput.coord_, inExprs );
+                cvals[ ic ] = new CoordValue( cinput.coord_, inExprs, dms );
             }
             StarTable table = clist_.get( 0 ).table_;  // must be same for all
             try {
@@ -478,11 +480,10 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
          * Aggregates a coordinate description and a GUI component
          * that can acquire a value for it in the context of a given table.
          */
-        @SuppressWarnings({"unchecked","rawtypes"})
         private static class CoordInput {
             final StarTable table_;
             final Coord coord_;
-            final JComboBox[] entryBoxes_;
+            final JComboBox<?>[] entryBoxes_;
 
             /**
              * Constructor.
@@ -494,11 +495,10 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
                 coord_ = coord;
                 table_ = table;
                 Input[] inputs = coord.getInputs();
-                entryBoxes_ = new JComboBox[ inputs.length ];
+                entryBoxes_ = new JComboBox<?>[ inputs.length ];
                 for ( int i = 0; i < inputs.length; i++ ) {
                     entryBoxes_[ i ] =
-                        createColumnEntryBox( table,
-                                              inputs[ i ].getValueClass() );
+                        createColumnEntryBox( table, inputs[ i ].getDomain() );
                 }
             }
 
@@ -507,10 +507,10 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
              * context of a given table.
              *
              * @param   table  table supplying data
-             * @param   clazz   requierd class for data column entries
+             * @param   domain   value domain for data column entries
              */
-            private static JComboBox createColumnEntryBox( StarTable table,
-                                                           Class<?> clazz ) {
+            private static JComboBox<?>
+                    createColumnEntryBox( StarTable table, Domain<?> domain ) {
 
                 /* Add an item to the combo box for each column with a
                  * value of the right type.  But you can also type in
@@ -520,12 +520,13 @@ public class BasicPlotGui<P,A,S extends Style> extends JPanel {
                 cnameList.add( null );
                 for ( int ic = 0; ic < ncol; ic++ ) {
                     ColumnInfo info = table.getColumnInfo( ic );
-                    if ( clazz.isAssignableFrom( info.getContentClass() ) ) {
+                    if ( domain.getPossibleMapper( info ) != null ) {
                         cnameList.add( info.getName() );
                     }
                 }
-                JComboBox combo =
-                    new JComboBox( cnameList.toArray( new String[ 0 ] ) );
+                JComboBox<?> combo =
+                    new JComboBox<Object>( cnameList
+                                          .toArray( new String[ 0 ] ) );
                 combo.setEditable( true );
                 combo.setSelectedItem( null );
                 return combo;
