@@ -518,6 +518,9 @@ public class PlotUtil {
         SubCloud[] subClouds =
             arrayConcat( SubCloud.createSubClouds( layers, true ),
                          SubCloud.createPartialSubClouds( layers, true ) );
+        if ( subClouds.length == 0 ) {
+            return;
+        }
         PointCloud cloud = new PointCloud( subClouds );
 
         /* Collect values for the represented points to mark out the basic
@@ -779,11 +782,7 @@ public class PlotUtil {
         else if ( iButt == MouseEvent.BUTTON2 ) {
             return 2;
         }
-        else if ( iButt == MouseEvent.NOBUTTON ) {
-            return 0;
-        }
-        else {
-            assert iButt == MouseEvent.BUTTON1;
+        else if ( iButt == MouseEvent.BUTTON1 ) {
             if ( ( exmods & InputEvent.CTRL_DOWN_MASK ) != 0 ) {
                 return 3;
             }
@@ -794,6 +793,13 @@ public class PlotUtil {
                 return 1;
             }
         }
+        else if ( iButt == MouseEvent.NOBUTTON ) {
+            return 0;
+        }
+        else {
+            // non-standard button - ignore it
+            return 0;
+        }
     }
 
     /**
