@@ -1,6 +1,7 @@
 package uk.ac.starlink.ttools.plot2.data;
 
 import java.io.IOException;
+import uk.ac.starlink.table.DomainMapper;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.ValueInfo;
@@ -157,11 +158,11 @@ public abstract class WrapperDataStoreFactory implements DataStoreFactory {
             return baseSpec_.getCoordCount();
         }
 
-        public Object getMaskId() {
+        public String getMaskId() {
             return baseSpec_.getMaskId();
         }
 
-        public Object getCoordId( int icoord ) {
+        public String getCoordId( int icoord ) {
             return baseSpec_.getCoordId( icoord );
         }
 
@@ -173,6 +174,10 @@ public abstract class WrapperDataStoreFactory implements DataStoreFactory {
             return baseSpec_.getUserCoordInfos( icoord );
         }
 
+        public DomainMapper[] getUserCoordMappers( int icoord ) {
+            return baseSpec_.getUserCoordMappers( icoord );
+        }
+
         public UserDataReader createUserDataReader() {
             return baseSpec_.createUserDataReader();
         }
